@@ -66,7 +66,11 @@ def vis_coco(coco_img_root, ann_f):
         img = coco.loadImgs(img_id)[0]
         print('checking img: {}, id: {}'.format(img, img_id))
 
-        img_f = os.path.join(data_dir, img['file_name'])
+        # img['file_name'] may be not basename
+        img_f = os.path.join(data_dir, os.path.basename(img['file_name']))
+        if not os.path.exists(img_f):
+            # if not then pull it back to normal mode
+            img_f = os.path.join(data_dir, img['file_name'])
         anno_ids = coco.getAnnIds(imgIds=img['id'])
         annos = coco.loadAnns(anno_ids)
 
@@ -106,7 +110,8 @@ def vis_coco(coco_img_root, ann_f):
             I = io.imread(img_f)
             plt.imshow(I)
             plt.axis('off')
-            coco.showAnns(annos)
+            coco.showAnns(annos, True)
             plt.show()
 
 
+
