@@ -28,11 +28,21 @@ also this will give options to draw detection or not
 
 
 """
+import torch
 import cv2
 import numpy as np
-from .common import get_unique_color_by_id
+from .common import get_unique_color_by_id, get_unique_color_by_id2, get_unique_color_by_id_with_dataset
 from .det import draw_one_bbox
 from PIL import Image
+from .get_dataset_color_map import create_cityscapes_label_colormap, create_ade20k_label_colormap, create_mapillary_vistas_label_colormap, create_pascal_label_colormap
+
+
+ALL_COLORS_MAP = {
+    "cityscapes": create_cityscapes_label_colormap(),
+    "mapillary": create_mapillary_vistas_label_colormap(),
+    "ade20k": create_ade20k_label_colormap(),
+    "voc": create_pascal_label_colormap(),
+}
 
 
 def draw_masks_maskrcnn(image, boxes, scores, labels, masks, human_label_list=None,
@@ -95,7 +105,8 @@ def draw_masks_maskrcnn(image, boxes, scores, labels, masks, human_label_list=No
                     line_thickness = 1
 
                     txt = '{} {:.2f}'.format(human_label_list[label], score)
-                    cv2.putText(image, txt, (x1, y1), font, font_scale, cls_color, font_thickness)
+                    cv2.putText(image, txt, (x1, y1), font,
+                                font_scale, cls_color, font_thickness)
 
             # colorize mask
             m_w = int(x2-x1)
@@ -119,7 +130,7 @@ def draw_masks_maskrcnn(image, boxes, scores, labels, masks, human_label_list=No
 
 
 def draw_masks_maskrcnn_v2(image, boxes, scores, labels, masks, human_label_list=None,
-                        score_thresh=0.6, draw_box=True):
+                           score_thresh=0.6, draw_box=True):
     """
     We change way to draw masks on image
 
@@ -167,7 +178,8 @@ def draw_masks_maskrcnn_v2(image, boxes, scores, labels, masks, human_label_list
                     line_thickness = 1
 
                     txt = '{} {:.2f}'.format(human_label_list[label], score)
-                    cv2.putText(image, txt, (x1, y1), font, font_scale, cls_color, font_thickness)
+                    cv2.putText(image, txt, (x1, y1), font,
+                                font_scale, cls_color, font_thickness)
 
             # colorize mask
             m_w = int(x2-x1)
@@ -187,4 +199,64 @@ def draw_masks_maskrcnn_v2(image, boxes, scores, labels, masks, human_label_list
     return combined
 
 
-# more fast mask drawing here
\ No newline at end of file
+# more fast mask drawing here
+def vis_bitmasks(img, bitmasks, fill_mask=True, return_combined=True, thickness=1):
+    """
+    visualize bitmasks on image
+    """
+    if isinstance(bitmasks, torch.Tensor):
+        bitmasks = bitmasks.cpu().numpy()
+
+    res_m = np.zeros_like(img)
+    assert isinstance(bitmasks, np.ndarray), 'bitmasks must be numpy array'
+    bitmasks = bitmasks.astype(np.uint8)
+    for i, m in enumerate(bitmasks):
+        cts, _ = cv2.findContours(m, cv2.RETR_TREE, cv2.CHAIN_APPROX_SIMPLE)
+        # inssue this is a unique color
+        c = get_unique_color_by_id2(i)
+        if return_combined:
+            if fill_mask:
+                cv2.drawContours(res_m, cts, -1,  color=c,
+                                 thickness=-1, lineType=cv2.LINE_AA)
+                cv2.drawContours(img, cts, -1,  color=c,
+                                 thickness=1, lineType=cv2.LINE_AA)
+            else:
+                cv2.drawContours(res_m, cts, -1,  color=c,
+                                 thickness=thickness, lineType=cv2.LINE_AA)
+        else:
+            if fill_mask:
+                cv2.drawContours(img, cts, -1,  color=c,
+                                 thickness=-1, lineType=cv2.LINE_AA)
+            else:
+                cv2.drawContours(img, cts, -1,  color=c,
+                                 thickness=thickness, lineType=cv2.LINE_AA)
+    if return_combined:
+        img = cv2.addWeighted(img, 0.9, res_m, 0.6, 0.8)
+        return img
+    else:
+        return img
+
+
+# helper functions
+def label2color_mask(cls_id_mask, max_classes=90, override_id_clr_map=None, color_suit='cityscapes'):
+    """
+    cls_id_mask is your segmentation output
+    override_id_clr_map: {2: [0, 0, 0]} used to override color
+    """
+    assert color_suit in ALL_COLORS_MAP.keys(
+    ), 'avaiable keys: {}'.format(ALL_COLORS_MAP.keys())
+    colors = ALL_COLORS_MAP[color_suit]
+    if override_id_clr_map != None:
+        if isinstance(override_id_clr_map, dict):
+            colors = np.array([get_unique_color_by_id_with_dataset(i) if i not in override_id_clr_map.keys(
+            ) else override_id_clr_map[i] for i in range(max_classes)])
+        else:
+            colors = np.array([override_id_clr_map[i % len(
+                override_id_clr_map)] for i in range(max_classes)])
+
+    s = cls_id_mask.shape
+    if len(s) > 1:
+        cls_id_mask = cls_id_mask.flatten()
+    mask = colors[cls_id_mask]
+    mask = np.reshape(mask, (*s, 3)).astype(np.uint8)
+    return mask
